@@ -161,13 +161,13 @@ void DataSourceFactory::slotFinishedDownload(TransferDataSource *source, KIO::fi
     m_speedTimer->stop();
     m_finished = true;
 }
-//FIXME is this even needed
+
 bool DataSourceFactory::checkLocalFile()
 {
     QString dest_orig = m_dest.toLocalFile();
     QString _dest_part(dest_orig);
 
-    /*KDE_struct_stat buff_part;
+    KDE_struct_stat buff_part;
     bool bPartExists = (KDE::stat( _dest_part, &buff_part ) != -1);
     if(!bPartExists)
     {
@@ -185,7 +185,7 @@ bool DataSourceFactory::checkLocalFile()
         {
             close(fd);
         }
-    }*///TODO: Port if needed
+    }//TODO: Port to use Qt functions maybe
 
     qCDebug(KGET_DEBUG) << "success";
     return true;
@@ -221,7 +221,7 @@ void DataSourceFactory::start()
     if (checkLocalFile()) {
         if (!m_putJob) {
             m_putJob = KIO::open(m_dest, QIODevice::WriteOnly | QIODevice::ReadOnly);
-            connect(m_putJob, SIGNAL(open(KIO::Job*)), this, SLOT(open(KIO::Job*)));
+            connect(m_putJob, SIGNAL(open(KIO::Job*)), this, SLOT(slotOpen(KIO::Job*)));
             connect(m_putJob, SIGNAL(destroyed(QObject*)), this, SLOT(slotPutJobDestroyed(QObject*)));
             m_startTried = true;
             return;
@@ -305,7 +305,7 @@ void DataSourceFactory::slotRemovedFile()
     }
 }
 
-void DataSourceFactory::open(KIO::Job *job)
+void DataSourceFactory::slotOpen(KIO::Job *job)
 {
     Q_UNUSED(job)
     qCDebug(KGET_DEBUG) << "File opened" << this;
