@@ -44,7 +44,7 @@ class MainWindow : public KXmlGuiWindow
 
 Q_OBJECT
 public:
-    explicit MainWindow(bool showMainwindow = true, bool startWithoutAnimation = false, bool doTesting = false, QWidget *parent = 0);
+    explicit MainWindow(bool showMainwindow = true, bool startWithoutAnimation = false, bool doTesting = false, QWidget *parent = nullptr);
     ~MainWindow();
 
     virtual void setSystemTrayDownloading(bool running);
@@ -155,7 +155,7 @@ private:
     bool m_startWithoutAnimation;
     bool m_doTesting;               // UnitTest flag
 
-    HttpServer *m_webinterface;
+    //HttpServer *m_webinterface;
 
 #ifdef HAVE_QCA2
     QCA::Initializer m_qcaInit;
