@@ -9,16 +9,17 @@
 */
 #include "btsettingswidget.h"
 
-#include "kget_export.h"
+#include "kget_macro.h"
 #include "bittorrentsettings.h"
 
-#include <kdebug.h>
+#include "kget_debug.h"
+#include <qdebug.h>
 #include <kfiledialog.h>
 
 KGET_EXPORT_PLUGIN_CONFIG(BTSettingsWidget)
 
 BTSettingsWidget::BTSettingsWidget(QWidget * parent, const QVariantList &args)
-  : KCModule(KGetFactory::componentData(), parent, args)
+  : KCModule(/*KGetFactory::componentData(),*/ parent, args)
 {
     setupUi(this);
 
@@ -34,15 +35,15 @@ BTSettingsWidget::BTSettingsWidget(QWidget * parent, const QVariantList &args)
 void BTSettingsWidget::load()
 {
     torrentEdit->setMode(KFile::Directory);
-    torrentEdit->fileDialog()->setCaption(i18n("Select a default torrent folder"));
+    torrentEdit->fileDialog()->setWindowTitle(i18n("Select a default torrent folder"));
     tempEdit->setMode(KFile::Directory);
-    tempEdit->fileDialog()->setCaption(i18n("Select a default temporary folder"));
+    tempEdit->fileDialog()->setWindowTitle(i18n("Select a default temporary folder"));
     defaults();
 }
 
 void BTSettingsWidget::save()
 {
-    kDebug(5001) << "Save Bittorrent-config";
+    qCDebug(KGET_DEBUG) << "Save Bittorrent-config";
     BittorrentSettings::setPort(portBox->value());
     BittorrentSettings::setUploadLimit(uploadBox->value());
     BittorrentSettings::setDownloadLimit(downloadBox->value());
@@ -51,7 +52,7 @@ void BTSettingsWidget::save()
     BittorrentSettings::setPreAlloc(preallocBox->isChecked());
     BittorrentSettings::setEnableUTP(utpBox->isChecked());
 
-    BittorrentSettings::self()->writeConfig();
+    BittorrentSettings::self()->save();
 }
 
 void BTSettingsWidget::defaults()
@@ -66,4 +67,5 @@ void BTSettingsWidget::defaults()
 }
 
 #include "btsettingswidget.moc"
+
  
