@@ -19,9 +19,9 @@
 
 #include "dlgmms.h"
 #include "mmssettings.h"
-#include "kget_export.h"
+#include "kget_macro.h"
 
-//KGET_EXPORT_PLUGIN_CONFIG(DlgMmsSettings)
+KGET_EXPORT_PLUGIN_CONFIG(DlgMmsSettings)
 
 DlgMmsSettings::DlgMmsSettings(QWidget *parent, const QVariantList &args)
     : KCModule(/*KGetFactory::componentData(), */parent, args)
@@ -42,5 +42,6 @@ void DlgMmsSettings::save()
     MmsSettings::self()->save();
 }
 
+#include "dlgmms.moc"
 
 
