@@ -12,12 +12,12 @@
 
 #include "multisegkiosettings.h"
 
-#include "kget_export.h"
+#include "kget_macro.h"
 
 KGET_EXPORT_PLUGIN_CONFIG(DlgSettingsWidget)
 
 DlgSettingsWidget::DlgSettingsWidget(QWidget *parent, const QVariantList &args)
-    : KCModule(KGetFactory::componentData(), parent, args)
+    : KCModule(/*KGetFactory::componentData(), */parent, args)
 {
     ui.setupUi(this);
 
@@ -40,12 +40,11 @@ void DlgSettingsWidget::load()
 
 void DlgSettingsWidget::save()
 {
-    kDebug(5001) << "Saving Multithreaded config";
     MultiSegKioSettings::setSegments(ui.numSegSpinBox->value());
     MultiSegKioSettings::setUseSearchEngines(ui.enginesCheckBox->isChecked());
     MultiSegKioSettings::setUseSearchVerification(ui.verificationCheckBox->isChecked());
 
-    MultiSegKioSettings::self()->writeConfig();
+    MultiSegKioSettings::self()->save();
 }
 
 #include "dlgmultisegkio.moc"
