@@ -13,13 +13,6 @@
 #include "ui_groupsettingsdialog.h"
 #include "../core/basedialog.h"
 
-#include <KDialog>
-
-#ifdef HAVE_NEPOMUK
-namespace Nepomuk2 {
-    class TagWidget;
-}
-#endif
 
 class TransferGroupHandler;
 
@@ -35,18 +28,10 @@ class GroupSettingsDialog : public KGetSaveSizeDialog
     private slots:
         void save();
 
-    private:
-#ifdef HAVE_NEPOMUK
-        void updateUsedTagsLineEdit();
-#endif //HAVE_NEPOMUK
-
     private:
         TransferGroupHandler* m_group;
         Ui::GroupSettingsDialog ui;
 
-#ifdef HAVE_NEPOMUK
-        Nepomuk2::TagWidget *m_tagWidget;
-#endif //HAVE_NEPOMUK
 };
 
 #endif
